@@ -1,22 +1,8 @@
 /*
- * Copyright 2015 Martin Gräßlin <mgraesslin@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WINDOWSYSTEM_H
 #define WINDOWSYSTEM_H
 
@@ -90,7 +76,6 @@ public:
     void connectNotify(const QMetaMethod &signal) override;
 
 private:
-    void setupKWaylandIntegration();
     KWayland::Client::PlasmaWindow *window(WId window) const;
 
     KWayland::Client::PlasmaShell *m_waylandPlasmaShell = nullptr;
